@@ -1,4 +1,4 @@
 rootProject.name = "mahjong-utils"
 
 includeBuild("build-scripts")
-include(":mahjong-utils-native-sharedlib")
+include(":mahjong-utils-entry")
